=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-03-31 00:43:21 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-04-09 08:12:42 +0000
@@ -247,6 +247,9 @@
         t = self.get_transport()
         if t.is_readonly():
             return
+        if not t.supports_unix_modebits():
+            # no sense testing on this transport
+            return
         # Test mkdir with a mode
         t.mkdir('dmode755', mode=0755)
         self.assertTransportMode(t, 'dmode755', 0755)

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-04-09 02:20:50 +0000
+++ bzrlib/transport/__init__.py	2006-04-09 08:12:42 +0000
@@ -609,6 +609,22 @@
         """Return true if this connection cannot be written to."""
         return False
 
+    def supports_unix_modebits(self):
+        """Return true if this transport can store and retrieve unix modebits.
+
+        (For example, 0700 to make a directory owner-private.)
+        
+        Note: most callers will not want to switch on this, but should rather 
+        just try and set permissions and let them be either stored or not.
+        This is intended mainly for the use of the test suite.
+        
+        Warning: this is not guaranteed to be accurate as sometimes we can't 
+        be sure: for example with vfat mounted on unix, or a windows sftp
+        server."""
+        # TODO: Perhaps return a e.g. TransportCharacteristics that can answer
+        # several questions about the transport.
+        return False
+
 
 def get_transport(base):
     """Open a transport to access a URL or directory.

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2006-03-31 00:43:21 +0000
+++ bzrlib/transport/local.py	2006-04-09 08:12:42 +0000
@@ -20,6 +20,7 @@
 
 import os
 import shutil
+import sys
 from stat import ST_MODE, S_ISDIR, ST_SIZE
 import tempfile
 import urllib
@@ -270,6 +271,14 @@
         except (IOError, OSError),e:
             self._translate_error(e, path)
 
+    def supports_unix_modebits(self):
+        if sys.platform == 'win32':
+            # anyone else?
+            return False
+        else:
+            return True
+
+
 
 class ScratchTransport(LocalTransport):
     """A transport that works in a temporary dir and cleans up after itself.

